from .. import Provider as PersonProvider


class Provider(PersonProvider):
    first_names_female = (
        "Авгия",
        "Авигея",
        "Авторка",
        "Аглая",
        "Аглоида",
        "Агнешка",
        "Адамина",
        "Адра",
        "Адрианиа",
        "Аела",
        "Айрен",
        "Аксентия",
        "Алания",
        "Албина",
        "Александрина",
        "Алексиа",
        "Аленка",
        "Алиана",
        "Алисия",
        "Алтая",
        "Амбър",
        "Амория",
        "АнаМария",
        "Анатолия",
        "Ангелка",
        "Андика",
        "Андриана",
        "Анелина",
        "анета",
        "Анза",
        "Анимира",
        "Аница",
        "Аномалия",
        "Антоалина",
        "Антонела",
        "Ануша",
        "Анхея-мей",
        "Аполинария",
        "Аралия",
        "Аркадия",
        "Арсена",
        "Аселина",
        "Асифа",
        "Астромерия",
        "Атина",
        "Аурора",
        "Багра",
        "Балина",
        "Бацислава",
        "Беатрис",
        "Бела",
        "Белисима",
        "Беломира",
        "Бенелена",
        "Берислава",
        "Бея",
        "Билена",
        "Бисера",
        "Биянка",
        "Благодатка",
        "Благосвета",
        "Богдалина",
        "Богородка",
        "Бодурка",
        "Божидара-силвестра",
        "Божинела",
        "Божурка",
        "Бонифация",
        "Борена",
        "Бориска",
        "Борянка",
        "Боца",
        "Бригита",
        "Бронислава",
        "Буна",
        "Буча",
        "Бързана",
        "Ваклина",
        "Валерия",
        "Валя",
        "Вангелия",
        "Ванухи",
        "Варта",
        "Васенка",
        "Василина",
        "Васка",
        "Вашиля",
        "Вежда",
        "Велиана",
        "Велинна",
        "Велиянка",
        "Венда",
        "Венеция",
        "Венислава",
        "Венчислава",
        "Верена",
        "Верислава",
        "Веса",
        "Веселинка",
        "Весна",
        "Веца",
        "Видима",
        "Виктория",
        "Вилия",
        "Вилхема",
        "Виолета",
        "Виржиния",
        "Витомира",
        "Вишка",
        "Владилена",
        "Владлена",
        "Водица",
        "Войнка",
        "Вула",
        "Възкресения",
        "Въльо",
        "Върбунка",
        "Въца",
        "Габи",
        "Галена",
        "Галина",
        "Галя",
        "Гануца",
        "Гвоздейка",
        "Гена",
        "Георгелена",
        "Георгица",
        "Герга",
        "Гердана",
        "Гертруда",
        "Гиздана",
        "Гичка",
        "Гордана",
        "Гория",
        "Гоца",
        "Графица",
        "Грета",
        "Гримяна",
        "Гроздинка",
        "Гуна",
        "Гъда",
        "Гълъбица",
        "Гюгра",
        "Гюргя",
        "Дакота",
        "Дамяна",
        "Данелина",
        "Данимира",
        "Данка",
        "Дарданела",
        "Дария",
        "Дафинка",
        "Деа",
        "Деви",
        "Делиана",
        "Деля",
        "Демирела",
        "Дениандра",
        "Дениславена",
        "Денница",
        "Десимиляна",
        "Десияна",
        "Дефлорина",
        "Дея",
        "Джана",
        "Джиневра",
        "Джулия",
        "Диана-Мария",
        "Дида",
        "Дилмана",
        "Димитра",
        "Димка",
        "Динна",
        "Добрина",
        "Дойка",
        "Доменика",
        "Доника",
        "Дора-Анна",
        "Дорина",
        "Доста",
        "Доча",
        "Драгица",
        "Дренка",
        "Дуда",
        "Душка",
        "Дюкяна",
        "Евангелина",
        "Евдокия",
        "Евридика",
        "Едита",
        "Ел",
        "Елдора",
        "Еленица",
        "Елеонета",
        "Ели",
        "Елиз",
        "Елина",
        "Елиса",
        "Елица",
        "Елма",
        "Елфида",
        "Емануила",
        "Емма",
        "Еница",
        "Ергана",
        "Ермиля",
        "Естела",
        "Ефимена",
        "Ефросиния",
        "Жаклин",
        "Жанин",
        "Жара",
        "Жейна",
        "Желязка",
        "Женимира",
        "Жива",
        "Живомира",
        "Жичка",
        "Жорка",
        "Жулиана",
        "Заека",
        "Занка",
        "Зафа",
        "Захаринка",
        "Звездемира",
        "Здравелина",
        "Здухостина",
        "Зинаида",
        "Златея",
        "Златка",
        "Златомира",
        "Зоичка",
        "Зорка",
        "Зузичка",
        "Ивалена",
        "ивамина",
        "Иванеса",
        "Иваничка",
        "Ивелиана",
        "Ивинка",
        "Иглика",
        "Изидора",
        "Илеана",
        "Илианна",
        "Илинда",
        "Илка",
        "Инан",
        "Инеса",
        "Ира",
        "Ирин",
        "Ирла",
        "Исихия",
        "Истилияна",
        "Йоана",
        "Йоанна",
        "Йованка",
        "Йоко",
        "Йолина",
        "Йона",
        "Йоника",
        "Йорданка",
        "Йоханна",
        "Кадифейка",
        "Калея",
        "Калина",
        "Калиса",
        "Калуда",
        "Камея",
        "Кануша",
        "Карамелита",
        "Карина",
        "Касиди",
        "Катастрофа",
        "Катинка",
        "Каунка",
        "Кветослава",
        "Керанка",
        "Кети",
        "Кино",
        "Кирка",
        "Китчица",
        "Клара",
        "Клеуна",
        "Клоя",
        "Кокимира",
        "Комара",
        "Константина",
        "Корнелия",
        "Костадинка",
        "Кралина",
        "Красидара",
        "Красияна",
        "Криси",
        "кристабела",
        "Кристиана",
        "Кристия",
        "Кръстанка",
        "Ксандриния",
        "Кунка",
        "Кьнина",
        "Лада",
        "Лазура",
        "Лалка",
        "Лариса",
        "Лаца",
        "Лека",
        "Ленче",
        "Летисия",
        "Либерта",
        "Лидийка",
        "Лика",
        "Лилия",
        "Лилянка",
        "Линда",
        "Лия",
        "Лозанка",
        "Лорена",
        "Лоти",
        "Луна",
        "Лъчезарка",
        "Любина",
        "Люблина",
        "Любослава",
        "Люляна",
        "Люсила",
        "Лянка",
        "Магдалена",
        "Мадлен",
        "Майя",
        "Максимилияна",
        "Малена",
        "Малтина",
        "Манолина",
        "Мара-антоанета",
        "Маргит",
        "Марен",
        "Мари-анри",
        "Марийка",
        "Маринета",
        "Мариотка",
        "Мария",
        "Мария-елена",
        "Мария-Хуана",
        "Марлена",
        "Маруся",
        "Маса",
        "Матка",
        "Маша",
        "Медиха",
        "Мелания",
        "Мелъди",
        "Меропа",
        "Миглена",
        "Мила",
        "Милара",
        "милдия",
        "Милиана",
        "Милост",
        "Мимоза",
        "Минка",
        "Миранза",
        "Мирена",
        "Миропа",
        "Мисла",
        "Митошка",
        "Михайлена",
        "Мишка",
        "Младлена",
        "Момера",
        "Моника",
        "Мортадела",
        "Мушана",
        "Наводненка",
        "Надка",
        "Найда",
        "Нани",
        "Настия",
        "Наташа",
        "Невена",
        "Негрита",
        "Неделяна",
        "Нейка",
        "Нелида",
        "Нелла",
        "Неолина",
        "Нешка",
        "Нигрита",
        "Никоела",
        "Николина",
        "Нионила",
        "Нона",
        "Норка",
        "Нурета",
        "Огнена",
        "Октавия",
        "Оливера",
        "Омана",
        "Орлеана",
        "Орхидея",
        "Павилия",
        "Павлина",
        "Палвира",
        "Паломина",
        "Панда",
        "Пантера",
        "Парашкевица",
        "Парунка",
        "Патриотка",
        "Паулина",
        "Паца",
        "Пейолина",
        "Пелина",
        "Пепелота",
        "Периана",
        "перуна",
        "Петинка",
        "Петрийка",
        "Петромира",
        "Петрушка",
        "Пешка",
        "Пламена",
        "Плодовитка",
        "Полексина",
        "Полин",
        "Правда",
        "Преса",
        "Прина",
        "Пролетина",
        "Простисвета",
        "Пупи",
        "Първолетка",
        "Рада",
        "Радиа",
        "Радимира",
        "Радка",
        "Радосвета",
        "Радостка",
        "Раинка",
        "Райничка",
        "Рамина",
        "Ревка",
        "Ренгия",
        "Риана",
        "Римма",
        "Рия",
        "Роза",
        "Розана",
        "Розета",
        "Розка",
        "Роксана",
        "Ромолета",
        "Роселина",
        "Росислава",
        "Ростислава",
        "Ружка",
        "Румислава",
        "Русалия",
        "Руска",
        "Сабина",
        "Савета",
        "Салина",
        "Санка",
        "Сарая",
        "Сахория",
        "Свежа",
        "Светла",
        "Светломира",
        "Свидна",
        "Свободка",
        "Севда",
        "севделина",
        "Севета",
        "Семенарка",
        "Сергелинка",
        "Сибила",
        "Сиена",
        "Силви",
        "Силвия-александра",
        "Силяна",
        "Симона",
        "Синтия",
        "Сисоя",
        "Скакалка",
        "Славея",
        "Славка",
        "Сладоледка",
        "Смехотерапия",
        "Смирна",
        "Снежинка",
        "Софийка",
        "Спасена",
        "Спасияна",
        "Спирела",
        "Стависара",
        "Стаматка",
        "Станиела",
        "Станимирка",
        "Сташа",
        "Стелина",
        "Стефани",
        "Стеяна",
        "Стоимена",
        "Столетка",
        "Стоянка",
        "Сузи",
        "Съвестина",
        "Сърменка",
        "Таисия",
        "тамара",
        "Таня",
        "Ташимира",
        "Теа",
        "Телефонка",
        "Темира",
        "Теодора",
        "Теса",
        "Тилиана",
        "Тиха",
        "Тоанета",
        "Толиана",
        "Тона",
        "Тоницвета",
        "Тоска",
        "Тошка",
        "Трендафила",
        "Трифонка",
        "Троша",
        "Труфана",
        "Тръпка",
        "Туфка",
        "Улиана",
        "Урима",
        "Фабияна",
        "Фатиме",
        "Феня",
        "Фикия",
        "Филипини",
        "Фимка",
        "Флавия",
        "Флорика",
        "Фотинка",
        "Фронка",
        "Фуга",
        "Хана",
        "Харитония",
        "Хенриета",
        "Хинка",
        "Холи",
        "Хранислава",
        "Хрисанка",
        "Христа",
        "Христела",
        "Христилияна",
        "Христоелена",
        "Христя",
        "Хубавелка",
        "Цанета",
        "Царевна",
        "Цветана",
        "Цветелина",
        "Цветилена",
        "Цветлина",
        "Цветолилия",
        "Цветяна",
        "Цеца",
        "Цола",
        "Цоня",
        "Чана",
        "Чардафона",
        "Чачия",
        "Череша",
        "Четвърта",
        "Чона",
        "Чубрина",
        "Шана",
        "Шена",
        "Шехерезада",
        "Шинка",
        "Щедра",
        "Щериана",
        "Щефания",
        "Щилянка",
        "Щтилка",
        "Ъгленка",
        "Ъчка",
        "Юлиена",
        "Юлия",
        "Юнона",
        "Юрита",
        "Юстианна",
        "Ябленка",
        "Явора",
        "Ягода",
        "Ялислава",
        "Яна-Мартина",
        "Янина",
        "Яниславия",
        "Янка",
        "Ярка",
        "Ясена",
        "Ятана",
    )

    first_names_male = (
        "Аблен",
        "Август",
        "Августиан",
        "Августин",
        "Авел",
        "Авер",
        "Аверно",
        "Авксентий",
        "Аво",
        "Аврам",
        "Аврели",
        "Аврелий",
        "Аврор",
        "Агапи",
        "Агапий",
        "Агатопод",
        "Агент",
        "Аглай",
        "Агнен",
        "Агнеш",
        "Агоп",
        "Агъци",
        "Адалберт",
        "Адам",
        "Адеан",
        "Аделин",
        "Адем",
        "Адриан",
        "Адриян",
        "Аерозол",
        "Азалия",
        "Айдемир",
        "Акашия",
        "Аксакусти",
        "Аксидан",
        "Аксинтия",
        "Алберт",
        "Албияна",
        "Алдин",
        "Алевандър",
        "Алег",
        "Алек",
        "Алекзандриян",
        "Беримир",
        "Берин",
        "Берия",
        "Беро",
        "Берослав",
        "Бетина",
        "Бетино",
        "Бечо",
        "Билян",
        "Бинко",
        "Биньо",
        "Бисенти",
        "Бисер",
        "Благо",
        "Благовест",
        "Благой",
        "Благомир",
        "Благосвет",
        "Блаже",
        "Бог",
        "Богиня",
        "Богой",
        "Боголюб",
        "Богомил",
        "Богослав",
        "Бодромир",
        "Божан",
        "Божидар",
        "Божик",
        "Божимир",
        "Божин",
        "Божинел",
        "Божко",
        "Божо",
        "Божур",
        "Боил",
        "Боила",
        "Бойко",
        "Бойчо",
        "Болен",
        "Болеслав",
        "Боне",
        "Бонислав",
        "Бонко",
        "Боно",
        "Веселин",
        "Весислав",
        "Весо",
        "Веспасиян",
        "Ветко",
        "Вечко",
        "Вигалот",
        "Виго",
        "Виделин",
        "Виден",
        "Видин",
        "Видослав",
        "Видю",
        "Викенти",
        "Виктор",
        "Вилиан",
        "Вилизар",
        "Вилизара",
        "Вилислав",
        "Вилиян",
        "Винету",
        "Винко",
        "Вино",
        "Винсънт",
        "Винченцо",
        "Виолет",
        "Виолин",
        "Висарион",
        "Виталий",
        "Витко",
        "Витлян",
        "Витомир",
        "Витош",
        "Вихрен",
        "Вихрони",
        "Вихър",
        "Вичо",
        "Виша",
        "Вишетин",
        "Вишню",
        "Влад",
        "Владилен",
        "Владимер",
        "Владимир",
        "Галентин",
        "Галиен",
        "Галимир",
        "Галиян",
        "Гани",
        "Ганислав",
        "Ганцомир",
        "Ганчо",
        "Ганьо",
        "Гаро",
        "Гатьо",
        "Гацо",
        "Гвардиана",
        "Гелемир",
        "Генади",
        "ГенадиВалериев",
        "Генадий",
        "Генислав",
        "Генко",
        "Гено",
        "Генчо",
        "Гео",
        "Геодим",
        "Геомил",
        "Георги",
        "Герасим",
        "Герган",
        "Гергей",
        "Гергелюб",
        "Гергин",
        "Гердан",
        "Герман",
        "Геро",
        "Герой",
        "Герчо",
        "Гетислав",
        "Гетко",
        "Гето",
        "Гецо",
        "Гечо",
        "Гешо",
        "Гивеза",
        "Гиздален",
        "Гико",
        "Гилдрой",
        "Делчо",
        "Делян",
        "Деляна",
        "Демир",
        "Демян",
        "Дениз",
        "Деника",
        "Денимир",
        "Денис",
        "Денислав",
        "Дениян",
        "Денчо",
        "Дердидас",
        "десилиан",
        "Десимир",
        "Десислав",
        "Деслав",
        "Деспин",
        "Деспинка",
        "Деспот",
        "Детелин",
        "Дечко",
        "Дечо",
        "Дечю",
        "Дешо",
        "Деян",
        "Джанер",
        "Джанко",
        "Джихад",
        "Джон-стефан",
        "Диаманди",
        "Диамантина",
        "Диан",
        "Диван(надядоДианидядоИван)",
        "Дивизие",
        "Дивизия",
        "Дивил",
        "Дидко",
        "Диего",
        "Дико",
        "Дилян",
        "Евстати",
        "Евстатий",
        "Евстахий",
        "Евтим",
        "Егор",
        "Едвин",
        "Едит",
        "Едрю",
        "Едуард",
        "Еким",
        "Ектар",
        "Ектор",
        "Елвис",
        "Елеан",
        "Електрон",
        "Елемаг",
        "Еленко",
        "Елиан",
        "Елиас",
        "Елиезер",
        "Елизабет",
        "Елин",
        "Елисей",
        "Елисия",
        "Елко",
        "Ельо",
        "Ема-Бела",
        "Еманоил",
        "Емануел",
        "Емануил",
        "Емил",
        "Емилиан",
        "Емилиян",
        "Ендо",
        "Енчо",
        "Еньо",
        "Еню",
        "Ервин",
        "Ередин",
        "Еремия",
        "Ерик",
        "Ерина",
        "Ерол",
        "Ерсен",
        "Есен",
        "Етиен",
        "Ефка",
        "Заварин",
        "Завен",
        "Замфир",
        "Занго",
        "Занко",
        "Запрян",
        "Зарко",
        "Зафер",
        "Зафир",
        "Захар",
        "Захари",
        "Захарин",
        "Захо",
        "Звездан",
        "Звездин",
        "Звездислав",
        "Звездиян",
        "Звездолет",
        "Звездомир",
        "Згура",
        "Здравелин",
        "Здравец",
        "Здравко",
        "Здравчо",
        "Зенгин",
        "Зика",
        "Зинко",
        "Зинови",
        "Златан",
        "Злати",
        "Златил",
        "Златимир",
        "Златиян",
        "Златко",
        "Златогор",
        "Златозар",
        "Златомир",
        "Златослав",
        "Златоцвет",
        "Златьо",
        "Золтан",
        "Илиомар",
        "Илич",
        "Илия",
        "Илиян",
        "Илко",
        "Илчо",
        "Имилиан",
        "Ингемунд",
        "Инко",
        "Инчо",
        "Иполит",
        "Ириан",
        "Ириней",
        "иринеус",
        "Ириян",
        "Ирко",
        "Ирма",
        "Ирник",
        "Исак",
        "Исидор",
        "Искрен",
        "Искър",
        "Исперих",
        "Истан",
        "Истатко",
        "Истилян",
        "Исус",
        "Итко",
        "Ихтиандър",
        "Ицо",
        "Ичо",
        "Йено",
        "Йеремия",
        "Йоан",
        "Йоан-Александър",
        "Йоан-иво",
        "Йован",
        "Йовица",
        "Йовко",
        "Йово",
        "Йовро",
        "Йовцо",
        "Йовчо",
        "Йожи",
        "Йоил",
        "Йолиян",
        "Йолко",
        "Карен",
        "Карим",
        "Карин",
        "Карло",
        "Кармен",
        "Каролин",
        "Карчо",
        "Катакомб",
        "Каталинка",
        "Катерин",
        "Кевин",
        "Кеворк",
        "Кери",
        "Кибер",
        "Кимба",
        "Кимбо",
        "Кимон",
        "Кимчо",
        "Кин",
        "Кинка",
        "Кинта",
        "Киприслав",
        "Киприян",
        "Кириен",
        "Кирил",
        "Кирчо",
        "Киряк",
        "Киряки",
        "Киряко",
        "Кис",
        "Кит",
        "Кито",
        "Китодар",
        "Китомир",
        "Клим",
        "Климент",
        "Кнут",
        "Козма",
        "Койно",
        "Койо",
        "Койчо",
        "Коко",
        "Коле",
        "Колчо",
        "Кольо",
        "Колю",
        "Комнин",
        "Лалко",
        "Лало",
        "Лальо",
        "Ламби",
        "Ламбо",
        "Ламбю",
        "Ланселот",
        "Ласкал",
        "Ласкар",
        "Ластър",
        "Латин",
        "Латко",
        "Латьо",
        "Латю",
        "ЛЕА-МАРИЯ",
        "Леандър",
        "Лев",
        "Левент",
        "Левчо",
        "Леко",
        "Ленин",
        "Ленко",
        "Леон",
        "Леонид",
        "Лесе",
        "Лефтер",
        "Лечо",
        "Лилко",
        "Лило",
        "Лилчо",
        "Лилян",
        "Лимон",
        "Липе",
        "Лихия",
        "Личо",
        "Ловчо",
        "Лозан",
        "Лозана",
        "Лозен",
        "Лора-софия",
        "Лоранс",
        "Лука",
        "Лукан",
        "Луко",
        "Лули",
        "Лулчо",
        "Лусио",
        "Лусия",
        "Маноел",
        "Манол",
        "Маноло",
        "Мантас",
        "Мануил",
        "Мануш",
        "МанчестърЮнайтед",
        "Манчо",
        "Маньо",
        "Маню",
        "Марангони",
        "Маргарит",
        "Марек",
        "Мариан",
        "Марий",
        "Марин",
        "Маринел",
        "Маринчо",
        "Марио",
        "Мариоллита",
        "Маритна",
        "Мариян",
        "Марк",
        "Марк-антоний",
        "Марко",
        "Маркус",
        "Мартен",
        "Мартин",
        "Мартиниян",
        "Маруш",
        "Марчело",
        "Маслина",
        "Матей",
        "Матьо",
        "Матю",
        "Махно",
        "Машо",
        "Медиан",
        "Мено",
        "Мерилин",
        "Месак",
        "Метакса",
        "Найо",
        "Найчо",
        "Наке",
        "Нако",
        "Нанко",
        "Нано",
        "Нансимир",
        "Нанчо",
        "Наню",
        "Нарцислав",
        "Наско",
        "Настимир",
        "Настрадин",
        "Натанаил",
        "Натко",
        "Наум",
        "Нафисат",
        "Нафтали",
        "Нацко",
        "Нацо",
        "Начиян",
        "Начко",
        "Начо",
        "Невен",
        "Невенко",
        "Невилиян",
        "Невян",
        "Негослав",
        "Неделин",
        "Неделчо",
        "Недислав",
        "Недко",
        "Недьо",
        "Недю",
        "Недялко",
        "Нейко",
        "Нейчо",
        "Нелко",
        "Нелчо",
        "Нене",
        "Ненко",
        "Ненсислав",
        "Ненчо",
        "Неокли",
        "Нерес",
        "Обретим",
        "Ованес",
        "Огин",
        "Огнемир",
        "Огнен",
        "Океан",
        "Олег",
        "Олек",
        "Олимпи",
        "Омар",
        "Омуртаг",
        "Оник",
        "Онуфри",
        "Ончо",
        "Орлин",
        "Ортодокси",
        "Орфей",
        "Орхидей",
        "Орце",
        "Оскар",
        "Оханес",
        "Павел",
        "Павелин",
        "Павко",
        "Павлик",
        "Павлин",
        "Павлинчо",
        "Павломир",
        "Паисий",
        "Пако",
        "Палми",
        "Палмиро",
        "Панай",
        "Панайот",
        "Панде",
        "Панделис",
        "Пане",
        "Панкртийян",
        "Пано",
        "Панталей",
        "Пантелей",
        "Панто",
        "Пантю",
        "Панчо",
        "Паолина",
        "Параскев",
        "Параход",
        "Парашкев",
        "Парашкеван",
        "Паруш",
        "Паско",
        "Паспанахил",
        "Пато",
        "Патрик",
        "Патьо",
        "Паулин",
        "Паун",
        "Пацо",
        "Пачо",
        "Пейко",
        "Пейо",
        "Пейодон",
        "Пейтан",
        "Пейчин",
        "Пейчо",
        "Пеко",
        "Пелай",
        "Пеле",
        "Пенко",
        "Пенчин",
        "Пенчо",
        "Пеньо",
        "Пеню",
        "Пео",
        "Пепино",
        "Пепислав",
        "Пепо",
        "Перикъл",
        "Персиана",
        "Персиян",
        "Перчо",
        "Петиконгрес",
        "Петкан",
        "Петко",
        "Пето",
        "Петраки",
        "Петрана",
        "Петринел",
        "Петрозар",
        "Петромил",
        "Рангел",
        "Рангел-любими",
        "Рандю",
        "Ранчо",
        "Расате",
        "Рафаил",
        "Рачко",
        "Рачо",
        "Рашко",
        "Рашо",
        "Раю",
        "Раян",
        "Реан",
        "Рем",
        "Риналдо",
        "Рис",
        "Ристя",
        "Ричард",
        "Ричерд",
        "Роберт",
        "Роберто",
        "Робин",
        "Робърт",
        "Рогелина",
        "Рогена",
        "Родан",
        "Родион",
        "Розалин",
        "Розин",
        "Розоцвет",
        "Ройо",
        "Роксан",
        "Ромел",
        "Ромелина",
        "Ромен",
        "Ромео",
        "Ромил",
        "Ромул",
        "Росен",
        "Росенка",
        "Росимир",
        "Роска",
        "Роско",
        "Ростиана",
        "Ростимир",
        "Ростислав",
        "Светломир",
        "Светлю",
        "Светозар",
        "Светослав",
        "Себастиан",
        "Себахтин",
        "Севан",
        "Севар",
        "Севастин",
        "Севдалин",
        "Севдан",
        "Севелин",
        "Северин",
        "Седеф",
        "Седефчо",
        "Селен",
        "Селена",
        "Сенко",
        "Серафим",
        "Сергей",
        "Сеслав",
        "Сиви",
        "Сидер",
        "Сидония",
        "Сидор",
        "Сиен",
        "Силаги",
        "Силан",
        "Силвестър",
        "Силвио",
        "Силвиян",
        "Силян",
        "Симеон",
        "Симо",
        "Сирман",
        "Сифоня",
        "Скорбут",
        "Слав",
        "Славдо",
        "Славе",
        "Славейко",
        "Славен",
        "Слави",
        "Славил",
        "Теодоси",
        "Теодосий",
        "Теодослав",
        "Теодостин",
        "Теофан",
        "Теохар",
        "Тервел",
        "Тигрони",
        "Тило",
        "Тильо",
        "Тимо",
        "Тимон",
        "Тимотей",
        "Тимчо",
        "Тино",
        "Тинчо",
        "Тихо",
        "Тихол",
        "Тихомир",
        "Тихон",
        "Тишо",
        "Тоде",
        "Тодомирка",
        "Тодораки",
        "Тодорин",
        "Тодорина",
        "Токимир",
        "Толек",
        "Толю",
        "Тома",
        "Томас",
        "Томен",
        "Томинка",
        "Томислав",
        "Томо",
        "Тоне",
        "Тони",
        "Тонимир",
        "Тонислав",
        "Тонко",
        "Тончо",
        "Топалко",
        "Тополко",
        "Тотко",
        "Тотьо",
        "Тотю",
        "Тоцо",
        "Филатей",
        "Фили",
        "Филидан",
        "Филион",
        "Филип",
        "Филипас",
        "Филипопол",
        "Филко",
        "Филомир",
        "Филчо",
        "Фильо",
        "Финдо",
        "Фиро",
        "Фирчо",
        "Фичо",
        "Флори",
        "Флориан",
        "Флорин",
        "Флоро",
        "Фори",
        "Фосил",
        "Франк",
        "Франц",
        "Францислав",
        "Фрацил",
        "Фреди",
        "Фродо",
        "Фуго",
        "Фуко",
        "Фъстък",
        "Фьодор",
        "Хавтелин",
        "Ханко",
        "Хараламби",
        "Харалампи",
        "Харалан",
        "Харбингър",
        "Хари",
        "Харизан",
        "Харитон",
        "Хасан",
        "Хасатин",
        "Хачо",
        "Хвойне",
        "Хебър",
        "Хектор",
        "Хераклит",
        "Хернани",
        "Хефестион",
        "Химинай",
        "Хинко",
        "Хино",
        "Хитко",
        "Хороз",
        "Храбрин",
        "Храбър",
        "Хранимир",
        "Хрелко",
        "Хрельо",
        "Хрисим",
        "Хрисимир",
        "Хрисо",
        "Христалин",
        "Христивилин",
        "Христиела",
        "Христилиан",
        "християн",
        "Христо",
        "Христо-никола",
        "Христодор",
        "Христозар",
        "Христозорнициан",
        "Христозорницомил",
        "Христомил",
        "Христомир",
        "Христослав",
        "Христофор",
        "Хрисчо",
        "Хрондел",
        "Хрусан",
        "Хубав",
        "Хубавен",
        "Хубан",
        "Хубен",
        "Цоню",
        "Цоцо",
        "Цочо",
        "Цъки",
        "Чавдар",
        "Чанкете",
        "Чанко",
        "Чано",
        "Чаньо",
        "Чардафон",
        "Чародей",
        "Чауш",
        "Чачо",
        "Чвор",
        "Чедомир",
        "Ченко",
        "Ченю",
        "Чепо",
        "Черноризец",
        "Черньо",
        "Чийо",
        "Чико",
        "Чило",
        "Чонар",
        "Чони",
        "Чоно",
        "Чоню",
        "Чочо",
        "Чочомир",
        "Чубрик",
        "Чуде",
        "Чудо",
        "Чудомир",
        "Чудослав",
        "Чук",
        "Шабан",
        "Шанко",
        "Шаноу",
        "Шаро",
        "Шейна",
        "Шеки",
        "Шенко",
        "Шенол",
        "Шибил",
        "Шидер",
        "Шинко",
        "Шино",
        "Шипчан",
        "Ширко",
        "Шишман",
        "Шкодри",
        "Шмильо",
        "Шмулю",
        "Шпилко",
        "Шушо",
        "Щедрин",
        "Щедю",
        "Щеки",
        "Щено",
        "Щеню",
        "Щерион",
        "Щериян",
        "Щерко",
        "Щерьо",
        "Щерю",
        "Щилиян",
        "Щилян",
        "Щирян",
        "Щоно",
        "Щтърбан",
        "Щтъркан",
        "Щурк",
        "Щърбан",
        "Щъркан",
        "Ъглен",
        "Ълен",
        "Ърнест",
        "Ъруин",
        "Ърчо",
        "Ьобирдар",
        "Юги",
        "Юлиан",
        "Юлий",
        "Юлиян",
        "Юрдан",
        "Юри",
        "Юрий",
        "Юстин",
        "Юстиниан",
        "Яблен",
        "Явор",
        "Яго",
        "Ягодин",
        "Язо",
        "Яким",
        "Яко",
        "Якоб",
        "Яков",
        "Якослав",
        "Ян",
        "Янадин",
        "Янаки",
        "Янакин",
        "Яначко",
        "Яне",
        "Янег",
        "Янедин",
        "Янек",
        "Яни",
        "Яниел",
        "Яник",
        "Янимир",
        "Янис",
        "Янислав",
        "Яничко",
        "Янко",
        "Янкул",
        "Яно",
        "Яномил",
        "Янтар",
        "Януш",
        "Янцислав",
        "Янче",
        "Янчо",
        "Ярно",
        "Яромир",
        "Ярце",
        "Ярчо",
        "Яръм",
        "Ярю",
        "Ясен",
        "Ясер",
        "Ястреб",
        "Ятан",
        "Яцо",
        "Ячо",
        "Яшар",
        "Яшка",
        "Яшо",
        "Яшон",
    )

    last_names_male = (
        "Симеонов",
        "Данданов",
        "Кърков",
        "Братухчев",
        "Цветков",
        "Иванов",
        "Яназов",
        "Тодоров",
        "Колчев",
        "Келешев",
        "Бърборков",
        "Дришльов",
        "Макаронски",
        "Количков",
        "Принов",
        "Бодуров",
        "Китов",
        "Гьоков",
        "Симеонов",
        "Балахуров",
        "Милачков",
        "ЕвроповКирилов",
        "Площаков",
        "Мангъров",
        "Хвърчилков",
        "Дзезов",
        "Ждраков",
        "Тухчиев",
        "Топков",
        "Яков",
        "Иликьов",
        "Бурханларски",
        "Вражалски",
        "Тутурилов",
        "Бранков",
        "Зенгинов",
        "Фенеров",
        "Кучев",
        "Възвъзов",
        "Кьоров",
        "Джогов",
        "Пъков",
        "Рангелов",
        "Чутурков",
        "Самсонов",
        "Андонов",
        "Бумов",
        "Мочев",
        "Дачев",
        "Муев",
        "Младенов",
        "Тошев",
        "Бедринов",
        "Тумангелов",
        "Канчин",
        "Миленков",
        "Патков",
        "Пондьов",
        "Самоходов",
        "Четрафилски",
        "Смърдански",
        "Клатуров",
        "Вакрилов",
        "Прошков",
        "Пулев",
        "Парашкевов",
        "Манавски",
        "Чуков",
        "Овнарски",
        "Рошльов",
        "Пройкова",
        "Младенова",
        "Кесьов",
        "Римпопов",
        "Златков",
        "Колев",
        "Пикянски",
        "Николов",
        "Цицков",
        "Стойков",
        "Каракашев",
        "Докова",
        "Мераков",
        "Пеева",
        "Педалов",
        "Тъпчилещов",
        "Въртунински",
        "Кодуков",
        "Татьозов",
        "Токов",
        "Юрганчев",
        "Клатикрушев",
        "Монтянов",
        "Бобев",
        "Топчийски",
        "Луланков",
        "Костов",
        "Колипатков",
        "Чукчуков",
        "Катъров",
        "Кобиларов",
        "Лимонадов",
        "Цоцов",
        "Поаков",
        "Недялков",
        "Станишев",
        "Йорданов",
        "Щърбов",
        "Занов",
    )

    last_names_female = (
        "Кокошкова",
        "Градинарова",
        "Куртакова",
        "Чанлиева",
        "Тодорова",
        "Пътечкова",
        "Скринска",
        "Сапунджиева",
        "Вампирска",
        "Васовa",
        "Таралингова",
        "Илиева",
        "Кривошапкова",
        "Чупетловска",
        "Катърова",
        "Бележкова",
        "Мустакова",
        "Пръндачка",
        "Йоткова",
        "Сланинкова",
        "Мангъфова",
        "Шкембова",
        "Пенджакова",
        "Пачаръзка",
        "Куртажова",
        "Плюнкова",
        "Многознаева",
        "Белоконска-Вражалска",
        "Кучкуделова",
        "Крушовска",
        "Пищовколева",
        "Сопаджиева",
        "Точева-Клопова",
        "Габровлиева",
        "Първанова",
        "Певецова",
        "Яркова",
        "Плюцова",
        "Балканска",
    )

    prefixes_female = ("Г-жа", "Г-ца", "Др.")
    prefixes_male = ("Г-н", "Др.")

    formats_female = (
        "{{first_name_female}} {{last_name_female}}",
        "{{prefix_female}} {{first_name_female}} {{last_name_female}}",
    )

    formats_male = (
        "{{first_name_male}} {{last_name_male}}",
        "{{prefix_female}} {{first_name_male}} {{last_name_male}}",
    )

    formats = formats_male + formats_female
    first_names = first_names_male + first_names_female
    last_names = last_names_male + last_names_female
