from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``fr_FR`` locale.

    Word list is drawn from the French Education Ministry's website Eduscol. The
    "lexical frequency list" can be found in the source(s) below.

    Sources:

    - http://eduscol.education.fr/cid47915/liste-des-mots-classee-par-ordre-alphabetique.html
    """

    word_list = (
        "à",
        "abandonner",
        "abattre",
        "abri",
        "absence",
        "absolu",
        "absolument",
        "accent",
        "accepter",
        "accompagner",
        "accomplir",
        "accord",
        "accorder",
        "accrocher",
        "accuser",
        "acheter",
        "achever",
        "acte",
        "action",
        "admettre",
        "adresser",
        "affaire",
        "affirmer",
        "afin de",
        "âgé",
        "âge",
        "agent",
        "agir",
        "agiter",
        "ah",
        "aide",
        "aider",
        "aile",
        "ailleurs",
        "aimer",
        "ainsi",
        "air",
        "ajouter",
        "aller",
        "allumer",
        "alors",
        "âme",
        "amener",
        "ami",
        "amour",
        "amuser",
        "an",
        "ancien",
        "anglais",
        "anglais",
        "angoisse",
        "animal",
        "animer",
        "année",
        "annoncer",
        "apercevoir",
        "apparaître",
        "apparence",
        "appartement",
        "appartenir",
        "appel",
        "appeler",
        "apporter",
        "apprendre",
        "approcher",
        "appuyer",
        "après",
        "après",
        "arbre",
        "argent",
        "arme",
        "armée",
        "armer",
        "arracher",
        "arrêter",
        "arrière",
        "arrivée",
        "arriver",
        "art",
        "article",
        "as",
        "aspect",
        "asseoir",
        "assez",
        "assister",
        "assurer",
        "attacher",
        "attaquer",
        "atteindre",
        "attendre",
        "attention",
        "attirer",
        "attitude",
        "au",
        "aucun",
        "aucun",
        "aujourd'hui",
        "auprès",
        "auquel",
        "aussi",
        "aussitôt",
        "autant",
        "auteur",
        "autorité",
        "autour",
        "autre",
        "autre",
        "autrefois",
        "autrement",
        "avance",
        "avancer",
        "avant",
        "avant",
        "avec",
        "avec",
        "avenir",
        "aventure",
        "avis",
        "avoir",
        "avouer",
        "baisser",
        "banc",
        "bande",
        "barbe",
        "bas",
        "bas",
        "bas",
        "bataille",
        "battre",
        "beau",
        "beau",
        "beau",
        "beaucoup",
        "beauté",
        "beaux",
        "besoin",
        "bête",
        "bien",
        "bien",
        "bientôt",
        "billet",
        "blanc",
        "blanc",
        "bleu",
        "blond",
        "boire",
        "bois",
        "bon",
        "bon",
        "bonheur",
        "bord",
        "bouche",
        "bout",
        "branche",
        "bras",
        "briller",
        "briser",
        "bruit",
        "brûler",
        "brusquement",
        "bureau",
        "but",
        "ça",
        "cabinet",
        "cacher",
        "calme",
        "calme",
        "calmer",
        "camarade",
        "campagne",
        "capable",
        "car",
        "caractère",
        "caresser",
        "carte",
        "cas",
        "casser",
        "cause",
        "causer",
        "ce",
        "ce",
        "ceci",
        "céder",
        "cela",
        "celui",
        "cent",
        "centre",
        "cependant",
        "cercle",
        "certain",
        "certain",
        "certainement",
        "certes",
        "cerveau",
        "cesse",
        "cesser",
        "chacun",
        "chaîne",
        "chair",
        "chaise",
        "chaleur",
        "chambre",
        "champ",
        "chance",
        "changement",
        "changer",
        "chant",
        "chanter",
        "chaque",
        "charge",
        "charger",
        "chasse",
        "chasser",
        "chat",
        "chaud",
        "chef",
        "chemin",
        "chemise",
        "cher",
        "chercher",
        "cheval",
        "cheveu",
        "chez",
        "chien",
        "chiffre",
        "choisir",
        "choix",
        "chose",
        "chute",
        "ci",
        "ciel",
        "cinq",
        "cinquante",
        "circonstance",
        "clair",
        "claire",
        "classe",
        "clef",
        "coeur",
        "coin",
        "colère",
        "colline",
        "colon",
        "combat",
        "combien",
        "commander",
        "comme",
        "comme",
        "commencement",
        "commencer",
        "comment",
        "comment",
        "commun",
        "compagnie",
        "compagnon",
        "complet",
        "complètement",
        "composer",
        "comprendre",
        "compte",
        "compter",
        "conclure",
        "condamner",
        "condition",
        "conduire",
        "confiance",
        "confier",
        "confondre",
        "connaissance",
        "connaître",
        "conscience",
        "conseil",
        "consentir",
        "considérer",
        "construire",
        "consulter",
        "contenir",
        "content",
        "contenter",
        "continuer",
        "contraire",
        "contre",
        "convenir",
        "conversation",
        "corde",
        "corps",
        "côte",
        "côté",
        "cou",
        "couche",
        "coucher",
        "couler",
        "couleur",
        "coup",
        "couper",
        "cour",
        "courage",
        "courant",
        "courir",
        "cours",
        "course",
        "court",
        "coûter",
        "couvrir",
        "craindre",
        "crainte",
        "créer",
        "creuser",
        "cri",
        "crier",
        "crise",
        "croire",
        "croiser",
        "croix",
        "cruel",
        "cuisine",
        "curieux",
        "curiosité",
        "d'abord",
        "dame",
        "danger",
        "dangereux",
        "dans",
        "danser",
        "d'autres",
        "d'autres",
        "davantage",
        "de",
        "de",
        "debout",
        "début",
        "déchirer",
        "décider",
        "déclarer",
        "découvrir",
        "décrire",
        "défaut",
        "défendre",
        "dégager",
        "dehors",
        "dehors",
        "déjà",
        "delà",
        "demain",
        "demain",
        "demande",
        "demander",
        "demeurer",
        "demi",
        "dent",
        "départ",
        "dépasser",
        "déposer",
        "depuis",
        "depuis",
        "dernier",
        "dernier",
        "derrière",
        "dès",
        "descendre",
        "désert",
        "désespoir",
        "désigner",
        "désir",
        "désirer",
        "désormais",
        "dessiner",
        "dessus",
        "détacher",
        "détail",
        "détruire",
        "deux",
        "devant",
        "devant",
        "devenir",
        "deviner",
        "devoir",
        "devoir",
        "dieu",
        "différent",
        "difficile",
        "digne",
        "dimanche",
        "dire",
        "direction",
        "diriger",
        "discours",
        "discussion",
        "discuter",
        "disparaître",
        "disposer",
        "distance",
        "distinguer",
        "divers",
        "dix",
        "docteur",
        "doigt",
        "dominer",
        "donc",
        "donner",
        "dont",
        "dormir",
        "dos",
        "double",
        "doucement",
        "douceur",
        "douleur",
        "doute",
        "douter",
        "doux",
        "douze",
        "drame",
        "dresser",
        "droit",
        "droit",
        "droite",
        "droite",
        "drôle",
        "du",
        "dur",
        "durant",
        "durer",
        "eau",
        "eaux",
        "écarter",
        "échapper",
        "éclairer",
        "éclat",
        "éclater",
        "école",
        "écouter",
        "écraser",
        "écrire",
        "effacer",
        "effet",
        "effort",
        "égal",
        "également",
        "eh",
        "élément",
        "élever",
        "elle",
        "éloigner",
        "embrasser",
        "emmener",
        "émotion",
        "empêcher",
        "empire",
        "employer",
        "emporter",
        "en",
        "en",
        "en",
        "encore",
        "endormir",
        "endroit",
        "énergie",
        "enfance",
        "enfant",
        "enfermer",
        "enfin",
        "enfoncer",
        "engager",
        "enlever",
        "ennemi",
        "énorme",
        "ensemble",
        "ensemble",
        "ensuite",
        "entendre",
        "entier",
        "entourer",
        "entraîner",
        "entre",
        "entrée",
        "entrer",
        "entretenir",
        "envelopper",
        "envie",
        "environ",
        "envoyer",
        "épais",
        "épaule",
        "époque",
        "éprouver",
        "erreur",
        "escalier",
        "espace",
        "espèce",
        "espérer",
        "espoir",
        "esprit",
        "essayer",
        "essuyer",
        "est",
        "et",
        "établir",
        "étage",
        "étaler",
        "état",
        "etc",
        "été",
        "éteindre",
        "étendre",
        "étendue",
        "éternel",
        "étoile",
        "étonner",
        "étouffer",
        "étrange",
        "étranger",
        "étranger",
        "être",
        "être",
        "étroit",
        "étude",
        "étudier",
        "événement",
        "éviter",
        "examiner",
        "exécuter",
        "exemple",
        "exiger",
        "existence",
        "exister",
        "expérience",
        "expliquer",
        "exposer",
        "expression",
        "exprimer",
        "extraordinaire",
        "face",
        "facile",
        "façon",
        "faible",
        "faim",
        "faire",
        "fait",
        "fait",
        "falloir",
        "famille",
        "fatigue",
        "fatiguer",
        "faute",
        "fauteuil",
        "faux",
        "faveur",
        "femme",
        "fenêtre",
        "fer",
        "ferme",
        "fermer",
        "fête",
        "feu",
        "feuille",
        "fidèle",
        "fier",
        "figure",
        "figurer",
        "fil",
        "fille",
        "fils",
        "fin",
        "fin",
        "fine",
        "finir",
        "fixe",
        "fixer",
        "flamme",
        "fleur",
        "flot",
        "foi",
        "fois",
        "folie",
        "fonction",
        "fond",
        "fonder",
        "force",
        "forcer",
        "forêt",
        "forme",
        "former",
        "fort",
        "fort",
        "fortune",
        "fou",
        "foule",
        "frais",
        "franc",
        "français",
        "français",
        "franchir",
        "françois",
        "frapper",
        "frère",
        "froid",
        "froid",
        "front",
        "fruit",
        "fuir",
        "fumée",
        "fumer",
        "fusil",
        "gagner",
        "garçon",
        "garde",
        "garder",
        "gauche",
        "gauche",
        "général",
        "général",
        "genou",
        "genre",
        "gens",
        "geste",
        "glace",
        "glisser",
        "gloire",
        "goût",
        "goutte",
        "gouvernement",
        "grâce",
        "grâce",
        "grain",
        "grand",
        "grand",
        "grandir",
        "grave",
        "gris",
        "gros",
        "groupe",
        "guère",
        "guerre",
        "habiller",
        "habitant",
        "habiter",
        "habitude",
        "haine",
        "haïr",
        "hasard",
        "haut",
        "haut",
        "haut",
        "haute",
        "hauteur",
        "herbe",
        "hésiter",
        "heure",
        "heureux",
        "hier",
        "histoire",
        "hiver",
        "homme",
        "honneur",
        "honte",
        "horizon",
        "hors",
        "hôtel",
        "huit",
        "humain",
        "humide",
        "ici",
        "idée",
        "ignorer",
        "il",
        "île",
        "image",
        "imaginer",
        "immense",
        "immobile",
        "importance",
        "important",
        "importer",
        "imposer",
        "impossible",
        "impression",
        "inconnu",
        "indiquer",
        "inquiéter",
        "inquiétude",
        "inspirer",
        "installer",
        "instant",
        "instinct",
        "intelligence",
        "intention",
        "intéresser",
        "intérêt",
        "intérieur",
        "intérieur",
        "interroger",
        "interrompre",
        "inutile",
        "inventer",
        "inviter",
        "jamais",
        "jambe",
        "jardin",
        "jaune",
        "je",
        "jeter",
        "jeu",
        "jeune",
        "jeune",
        "jeunesse",
        "joie",
        "joindre",
        "joli",
        "joue",
        "jouer",
        "jour",
        "journal",
        "journée",
        "juge",
        "juger",
        "jusque",
        "juste",
        "justice",
        "là",
        "large",
        "larme",
        "le",
        "le",
        "léger",
        "lendemain",
        "lentement",
        "lequel",
        "lettre",
        "leur",
        "leur",
        "lever",
        "lèvre",
        "liberté",
        "libre",
        "lien",
        "lier",
        "lieu",
        "ligne",
        "lire",
        "lisser",
        "lit",
        "livre",
        "livrer",
        "loi",
        "loin",
        "long",
        "long",
        "longtemps",
        "lors",
        "lorsque",
        "loup",
        "lourd",
        "lueur",
        "lui",
        "lumière",
        "l'un",
        "l'une",
        "lune",
        "lutte",
        "lutter",
        "machine",
        "madame",
        "magnifique",
        "main",
        "maintenant",
        "maintenir",
        "mais",
        "maison",
        "maître",
        "mal",
        "mal",
        "malade",
        "maladie",
        "malgré",
        "malheur",
        "manger",
        "manier",
        "manquer",
        "marchand",
        "marché",
        "marche",
        "marcher",
        "mari",
        "mari",
        "mariage",
        "marier",
        "marquer",
        "masse",
        "matière",
        "matin",
        "mauvais",
        "me",
        "médecin",
        "meilleur",
        "mêler",
        "membre",
        "même",
        "même",
        "même",
        "mémoire",
        "menacer",
        "mener",
        "mensonge",
        "mentir",
        "mer",
        "mériter",
        "mesure",
        "métier",
        "mettre",
        "midi",
        "mien",
        "mieux",
        "milieu",
        "militaire",
        "mille",
        "million",
        "mince",
        "mine",
        "ministre",
        "minute",
        "miser",
        "mode",
        "moi",
        "moindre",
        "moins",
        "mois",
        "moitié",
        "moment",
        "mon",
        "monde",
        "monsieur",
        "montagne",
        "monter",
        "montrer",
        "morceau",
        "mort",
        "mort",
        "mot",
        "mourir",
        "mouvement",
        "moyen",
        "moyen",
        "muet",
        "mur",
        "musique",
        "naissance",
        "naître",
        "nation",
        "nature",
        "naturel",
        "naturellement",
        "ne",
        "nécessaire",
        "nerveux",
        "neuf",
        "neuf",
        "nez",
        "ni",
        "noir",
        "noir",
        "noire",
        "nom",
        "nombre",
        "nombreux",
        "nommer",
        "non",
        "nord",
        "note",
        "notre",
        "nourrir",
        "nous",
        "nouveau",
        "nouveau",
        "nu",
        "nuage",
        "nuit",
        "nul",
        "obéir",
        "objet",
        "obliger",
        "observer",
        "obtenir",
        "occasion",
        "occuper",
        "odeur",
        "oeil",
        "oeuvre",
        "officier",
        "offrir",
        "oh",
        "oiseau",
        "ombre",
        "on",
        "oncle",
        "or",
        "or",
        "ordre",
        "oreille",
        "oser",
        "ou",
        "où",
        "oublier",
        "oui",
        "ouvert",
        "ouvrage",
        "ouvrir",
        "page",
        "pain",
        "paix",
        "palais",
        "papa",
        "papier",
        "paquet",
        "par",
        "paraître",
        "parce que",
        "parcourir",
        "pareil",
        "parent",
        "parfaitement",
        "parfois",
        "parler",
        "parmi",
        "parole",
        "part",
        "partager",
        "parti",
        "particulier",
        "partie",
        "partir",
        "partout",
        "parvenir",
        "pas",
        "pas",
        "passage",
        "passé",
        "passé",
        "passer",
        "passion",
        "patron",
        "paupière",
        "pauvre",
        "pauvre",
        "payer",
        "pays",
        "paysage",
        "paysan",
        "peau",
        "peine",
        "pencher",
        "pendant",
        "pendre",
        "pénétrer",
        "pensée",
        "penser",
        "perdre",
        "perdu",
        "père",
        "permettre",
        "personnage",
        "personne",
        "personne",
        "perte",
        "peser",
        "petit",
        "petit",
        "peu",
        "peuple",
        "peur",
        "phrase",
        "pièce",
        "pied",
        "pierre",
        "pitié",
        "place",
        "placer",
        "plaindre",
        "plaine",
        "plaire",
        "plaisir",
        "plan",
        "planche",
        "plante",
        "plein",
        "plein",
        "pleurer",
        "plonger",
        "pluie",
        "plus",
        "plusieurs",
        "plutôt",
        "poche",
        "poésie",
        "poète",
        "poids",
        "point",
        "point",
        "pointe",
        "poitrine",
        "police",
        "politique",
        "politique",
        "pont",
        "port",
        "porte",
        "porter",
        "portier",
        "poser",
        "position",
        "posséder",
        "possible",
        "poste",
        "pour",
        "pourquoi",
        "pourquoi",
        "poursuivre",
        "pourtant",
        "pousser",
        "poussière",
        "pouvoir",
        "pouvoir",
        "précéder",
        "précieux",
        "précipiter",
        "précis",
        "préférer",
        "premier",
        "premier",
        "prendre",
        "préparer",
        "près",
        "près",
        "présence",
        "présent",
        "présent",
        "présenter",
        "président",
        "presque",
        "presser",
        "prêt",
        "prétendre",
        "prêter",
        "preuve",
        "prévenir",
        "prévoir",
        "prier",
        "prière",
        "prince",
        "principe",
        "printemps",
        "prison",
        "prix",
        "problème",
        "prochain",
        "produire",
        "professeur",
        "profiter",
        "profond",
        "profondément",
        "projet",
        "promener",
        "promettre",
        "prononcer",
        "propos",
        "proposer",
        "propre",
        "protéger",
        "prouver",
        "public",
        "public",
        "puis",
        "puis",
        "puisque",
        "puissance",
        "puissant",
        "pur",
        "qualité",
        "quand",
        "quant à",
        "quarante",
        "quart",
        "quartier",
        "quatre",
        "que",
        "que",
        "quel",
        "quelque",
        "quelque",
        "quelqu'un",
        "question",
        "queue",
        "qui",
        "quinze",
        "quitter",
        "quoi",
        "race",
        "raconter",
        "raison",
        "ramasser",
        "ramener",
        "rang",
        "rapide",
        "rapidement",
        "rappeler",
        "rapport",
        "rapporter",
        "rare",
        "rassurer",
        "rayon",
        "réalité",
        "recevoir",
        "recherche",
        "réclamer",
        "recommencer",
        "reconnaître",
        "recueillir",
        "reculer",
        "réduire",
        "réel",
        "réfléchir",
        "réflexion",
        "refuser",
        "regard",
        "regarder",
        "règle",
        "regretter",
        "rejeter",
        "rejoindre",
        "relation",
        "relever",
        "religion",
        "remarquer",
        "remercier",
        "remettre",
        "remonter",
        "remplacer",
        "remplir",
        "rencontre",
        "rencontrer",
        "rendre",
        "renoncer",
        "rentrer",
        "renverser",
        "répandre",
        "repas",
        "répéter",
        "répondre",
        "réponse",
        "reposer",
        "repousser",
        "reprendre",
        "représenter",
        "réserver",
        "résistance",
        "résister",
        "résoudre",
        "respect",
        "respecter",
        "respirer",
        "ressembler",
        "reste",
        "rester",
        "résultat",
        "retenir",
        "retirer",
        "retomber",
        "retour",
        "retourner",
        "retrouver",
        "réunir",
        "réussir",
        "rêve",
        "réveiller",
        "révéler",
        "revenir",
        "rêver",
        "revoir",
        "révolution",
        "riche",
        "rideau",
        "rien",
        "rire",
        "rire",
        "risquer",
        "robe",
        "roche",
        "rocher",
        "roi",
        "rôle",
        "roman",
        "rompre",
        "rond",
        "rose",
        "rose",
        "rouge",
        "rouge",
        "rouler",
        "route",
        "rue",
        "ruine",
        "sable",
        "sac",
        "saint",
        "saint",
        "saisir",
        "saison",
        "salle",
        "saluer",
        "salut",
        "sang",
        "sans",
        "santé",
        "satisfaire",
        "sauter",
        "sauvage",
        "sauver",
        "savoir",
        "savoir",
        "scène",
        "science",
        "se",
        "sec",
        "second",
        "seconde",
        "secours",
        "secret",
        "secret",
        "secrétaire",
        "seigneur",
        "sein",
        "selon",
        "semaine",
        "semblable",
        "sembler",
        "sens",
        "sentier",
        "sentiment",
        "sentir",
        "séparer",
        "sept",
        "sérieux",
        "serrer",
        "service",
        "servir",
        "seuil",
        "seul",
        "seulement",
        "si",
        "si",
        "siècle",
        "siège",
        "sien",
        "signe",
        "signer",
        "signifier",
        "silence",
        "silencieux",
        "simple",
        "simplement",
        "situation",
        "six",
        "social",
        "société",
        "soi",
        "soin",
        "soir",
        "soirée",
        "soit",
        "sol",
        "soldat",
        "soleil",
        "solitude",
        "sombre",
        "somme",
        "sommeil",
        "sommet",
        "son",
        "son",
        "songer",
        "sonner",
        "sorte",
        "sortir",
        "sou",
        "soudain",
        "souffler",
        "souffrance",
        "souffrir",
        "souhaiter",
        "soulever",
        "soumettre",
        "source",
        "sourd",
        "sourire",
        "sourire",
        "sous",
        "soutenir",
        "souvenir",
        "souvenir",
        "souvent",
        "spectacle",
        "subir",
        "succès",
        "sueur",
        "suffire",
        "suite",
        "suivant",
        "suivre",
        "sujet",
        "supérieur",
        "supporter",
        "supposer",
        "sûr",
        "sur",
        "surprendre",
        "surtout",
        "surveiller",
        "système",
        "table",
        "tâche",
        "tache",
        "taille",
        "taire",
        "tandis que",
        "tant",
        "tantôt",
        "tapis",
        "tard",
        "te",
        "tel",
        "tellement",
        "témoin",
        "tempête",
        "temps",
        "tendre",
        "tendre",
        "tenir",
        "tenter",
        "terme",
        "terminer",
        "terrain",
        "terre",
        "terreur",
        "terrible",
        "tête",
        "théâtre",
        "tirer",
        "titre",
        "toi",
        "toile",
        "toit",
        "tombe",
        "tomber",
        "ton",
        "ton",
        "tôt",
        "toucher",
        "toujours",
        "tour",
        "tourner",
        "tout",
        "tout",
        "tout",
        "tout",
        "toute",
        "trace",
        "tracer",
        "train",
        "traîner",
        "trait",
        "traiter",
        "tranquille",
        "transformer",
        "travail",
        "travailler",
        "travers",
        "traverser",
        "trembler",
        "trente",
        "très",
        "trésor",
        "triste",
        "trois",
        "troisième",
        "tromper",
        "trop",
        "trou",
        "troubler",
        "trouver",
        "tu",
        "tuer",
        "type",
        "un",
        "un",
        "un",
        "unique",
        "usage",
        "user",
        "vague",
        "vague",
        "vaincre",
        "valeur",
        "valoir",
        "vaste",
        "veille",
        "veiller",
        "vendre",
        "venir",
        "vent",
        "ventre",
        "véritable",
        "vérité",
        "verre",
        "vers",
        "vers",
        "verser",
        "vert",
        "vêtement",
        "vêtir",
        "victime",
        "vide",
        "vide",
        "vie",
        "vieil",
        "vieillard",
        "vieux",
        "vieux",
        "vif",
        "village",
        "ville",
        "vin",
        "vingt",
        "violence",
        "violent",
        "visage",
        "visible",
        "vision",
        "visite",
        "vite",
        "vivant",
        "vivre",
        "voici",
        "voie",
        "voilà",
        "voile",
        "voir",
        "voisin",
        "voisin",
        "voiture",
        "voix",
        "vol",
        "voler",
        "volonté",
        "votre",
        "vouloir",
        "vous",
        "voyage",
        "voyager",
        "vrai",
        "vraiment",
        "vue",
        "y",
        "yeux",
    )

    parts_of_speech: Dict[str, tuple] = {}
